@@ -37,6 +37,7 @@
                       // reset_host_errors
 #include "sql_acl.h"  // acl_getroot, NO_ACCESS, SUPER_ACL
 #include "sql_callback.h"
+#include "debug_sync.h"
 
 
 #if defined(HAVE_OPENSSL) && !defined(EMBEDDED_LIBRARY)
@@ -1391,6 +1392,14 @@ void do_handle_one_connection(THD *thd_arg)
   if (setup_connection_thread_globals(thd))
     return;
 
+  DBUG_EXECUTE_IF("after_thread_setup",
+                  {
+                  const char act[]=
+                  "now signal thread_setup";
+                  DBUG_ASSERT(!debug_sync_set_action(current_thd,
+                                                     STRING_WITH_LEN(act)));
+                  };);
+
   for (;;)
   {
     bool rc;
